 
//////////////// include libraries
#include <XBee.h>
#include <SPI.h>
#include <SD.h>

//////////////// code settings

// max length of packet's payload (ie data)
#define PKT_MAX_LEN 100
// NOTE: needs to be larger than max size of packet payload
// FIXME: check max packet size... might be 110 bytes, but that might include header

//////////////// include external code
/* 
this file contains several functions used in the below code
which were moved to a separate file solely to reduce clutter
in this code (which is the only code which should need to be
modified.
*/
#include "functions.h"

//////////////// initalize variables
#define PKT_MAX_LEN 100

// ship select pin for SD logging
const int chipSelect = 4;

// object for holding packets received over xbee
Rx16Response reponse16 = Rx16Response();

// XBee address of xbee (should be unique)
uint16_t XBee_MY_Addr = 0x0001;

// PAN ID of xbee (must match all xbees)
uint16_t XBee_PAN_ID = 0x0B0B;

// initialize array to hold data received from xbee
uint8_t data[PKT_MAX_LEN];

uint8_t rcvd_data[PKT_MAX_LEN];

//////////////// setup function
void setup() {
  
  // start the serial
  Serial.begin(9600);

  int XbeeStatus = InitXBee(XBee_MY_Addr,XBee_PAN_ID);
  if(!XbeeStatus){
      Serial.println(F("Xbee initialized!"));
  }
  else{
      Serial.print(F("Xbee failed to initialize with Error code: "));
      Serial.println(XbeeStatus);
  }

  // initalize the SD card for logging
  if (!SD.begin(chipSelect)) {
    Serial.println(F("Card failed, or not present"));
    
  }
  else{
    Serial.println(F("card initialized."));
  }

}

//////////////// loop function
void loop() {
       
    if(readMsg(rcvd_data, 1) > 0){
    
      // its a request for a HK packet
       if(rcvd_data[4] == 0xAB && rcvd_data[5] == 0xCD){
         Serial.print("Sending HK Pkt to ");
         Serial.println(extract_uint16(rcvd_data, 2));
         sentHKpkt(extract_uint16(rcvd_data, 2));
       }
       // otherwise, log the data we received
       else{
      
        // open the SD card file for writing
        File dataFile = SD.open("datalog.txt", FILE_WRITE);
        
        String data_Str = data2string(rcvd_data);
        
        // log the packet to the SD card
        dataFile.println(data_Str);
      
        // write the changes to the log file
        dataFile.close();
        
        // write the data to the serial port
        Serial.println(data_Str);
        
       }
    }
    

        
    // delay for a bit
    delay(100);
}
